/*******************************************************************************
* File Name: SOC.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_SOC_H) /* Pins SOC_H */
#define CY_PINS_SOC_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "SOC_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 SOC__PORT == 15 && ((SOC__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    SOC_Write(uint8 value);
void    SOC_SetDriveMode(uint8 mode);
uint8   SOC_ReadDataReg(void);
uint8   SOC_Read(void);
void    SOC_SetInterruptMode(uint16 position, uint16 mode);
uint8   SOC_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the SOC_SetDriveMode() function.
     *  @{
     */
        #define SOC_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define SOC_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define SOC_DM_RES_UP          PIN_DM_RES_UP
        #define SOC_DM_RES_DWN         PIN_DM_RES_DWN
        #define SOC_DM_OD_LO           PIN_DM_OD_LO
        #define SOC_DM_OD_HI           PIN_DM_OD_HI
        #define SOC_DM_STRONG          PIN_DM_STRONG
        #define SOC_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define SOC_MASK               SOC__MASK
#define SOC_SHIFT              SOC__SHIFT
#define SOC_WIDTH              1u

/* Interrupt constants */
#if defined(SOC__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in SOC_SetInterruptMode() function.
     *  @{
     */
        #define SOC_INTR_NONE      (uint16)(0x0000u)
        #define SOC_INTR_RISING    (uint16)(0x0001u)
        #define SOC_INTR_FALLING   (uint16)(0x0002u)
        #define SOC_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define SOC_INTR_MASK      (0x01u) 
#endif /* (SOC__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define SOC_PS                     (* (reg8 *) SOC__PS)
/* Data Register */
#define SOC_DR                     (* (reg8 *) SOC__DR)
/* Port Number */
#define SOC_PRT_NUM                (* (reg8 *) SOC__PRT) 
/* Connect to Analog Globals */                                                  
#define SOC_AG                     (* (reg8 *) SOC__AG)                       
/* Analog MUX bux enable */
#define SOC_AMUX                   (* (reg8 *) SOC__AMUX) 
/* Bidirectional Enable */                                                        
#define SOC_BIE                    (* (reg8 *) SOC__BIE)
/* Bit-mask for Aliased Register Access */
#define SOC_BIT_MASK               (* (reg8 *) SOC__BIT_MASK)
/* Bypass Enable */
#define SOC_BYP                    (* (reg8 *) SOC__BYP)
/* Port wide control signals */                                                   
#define SOC_CTL                    (* (reg8 *) SOC__CTL)
/* Drive Modes */
#define SOC_DM0                    (* (reg8 *) SOC__DM0) 
#define SOC_DM1                    (* (reg8 *) SOC__DM1)
#define SOC_DM2                    (* (reg8 *) SOC__DM2) 
/* Input Buffer Disable Override */
#define SOC_INP_DIS                (* (reg8 *) SOC__INP_DIS)
/* LCD Common or Segment Drive */
#define SOC_LCD_COM_SEG            (* (reg8 *) SOC__LCD_COM_SEG)
/* Enable Segment LCD */
#define SOC_LCD_EN                 (* (reg8 *) SOC__LCD_EN)
/* Slew Rate Control */
#define SOC_SLW                    (* (reg8 *) SOC__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define SOC_PRTDSI__CAPS_SEL       (* (reg8 *) SOC__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define SOC_PRTDSI__DBL_SYNC_IN    (* (reg8 *) SOC__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define SOC_PRTDSI__OE_SEL0        (* (reg8 *) SOC__PRTDSI__OE_SEL0) 
#define SOC_PRTDSI__OE_SEL1        (* (reg8 *) SOC__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define SOC_PRTDSI__OUT_SEL0       (* (reg8 *) SOC__PRTDSI__OUT_SEL0) 
#define SOC_PRTDSI__OUT_SEL1       (* (reg8 *) SOC__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define SOC_PRTDSI__SYNC_OUT       (* (reg8 *) SOC__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(SOC__SIO_CFG)
    #define SOC_SIO_HYST_EN        (* (reg8 *) SOC__SIO_HYST_EN)
    #define SOC_SIO_REG_HIFREQ     (* (reg8 *) SOC__SIO_REG_HIFREQ)
    #define SOC_SIO_CFG            (* (reg8 *) SOC__SIO_CFG)
    #define SOC_SIO_DIFF           (* (reg8 *) SOC__SIO_DIFF)
#endif /* (SOC__SIO_CFG) */

/* Interrupt Registers */
#if defined(SOC__INTSTAT)
    #define SOC_INTSTAT            (* (reg8 *) SOC__INTSTAT)
    #define SOC_SNAP               (* (reg8 *) SOC__SNAP)
    
	#define SOC_0_INTTYPE_REG 		(* (reg8 *) SOC__0__INTTYPE)
#endif /* (SOC__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_SOC_H */


/* [] END OF FILE */
